@@ -1,6 +1,7 @@
 from sqlalchemy import Column
 from sqlalchemy import DateTime
 from sqlalchemy import String
+from sqlalchemy import Integer
 from sqlalchemy.dialects.mysql import SMALLINT
 from sqlalchemy.dialects.mysql import TINYINT
 
@@ -10,6 +11,7 @@ from .base import Base
 class Report(Base):
     __tablename__ = 'report'
 
+    id = Column(Integer, primary_key=True, autoincrement=True)
     licence_plate = Column(String(12), nullable=False)
     entry_point_camera_id = Column(TINYINT(4), nullable=False, default=1)
     arrived_to_entry_point = Column(DateTime, nullable=False)
